<?php
/**
 * The own template engine for loading caching and sending out the web pages
 * and emails.
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class WebTemplateEngine extends BaseTemplateEngine implements CompileableTemplate {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set part description
		$this->setObjectDescription("Web template engine");

		// Create unique ID number
		$this->generateUniqueId();

		// Clean up a little
		$this->removeNumberFormaters();
		$this->removeSystemArray();
	}

	/**
	 * Creates an instance of the class TemplateEngine and prepares it for usage
	 *
	 * @param	$basePath		The local base path for all templates
	 * @param	$langInstance	An instance of LanguageSystem (default)
	 * @param	$ioInstance		An instance of FileIoHandler (default, middleware!)
	 * @return	$tplInstance	An instance of TemplateEngine
	 * @throws	BasePathIsEmptyException		If the provided $basePath is empty
	 * @throws	InvalidBasePathStringException	If $basePath is no string
	 * @throws	BasePathIsNoDirectoryException	If $basePath is no
	 *											directory or not found
	 * @throws	BasePathReadProtectedException	If $basePath is
	 *											read-protected
	 */
	public final static function createWebTemplateEngine ($basePath, ManageableLanguage  $langInstance, FileIoHandler $ioInstance) {
		// Get a new instance
		$tplInstance = new WebTemplateEngine();

		// Is the base path valid?
		if (empty($basePath)) {
			// Base path is empty
			throw new BasePathIsEmptyException($tplInstance, self::EXCEPTION_UNEXPECTED_EMPTY_STRING);
		} elseif (!is_string($basePath)) {
			// Is not a string
			throw new InvalidBasePathStringException(array($tplInstance, $basePath), self::EXCEPTION_INVALID_STRING);
		} elseif (!is_dir($basePath)) {
			// Is not a path
			throw new BasePathIsNoDirectoryException(array($tplInstance, $basePath), self::EXCEPTION_INVALID_PATH_NAME);
		} elseif (!is_readable($basePath)) {
			// Is not readable
			throw new BasePathReadProtectedException(array($tplInstance, $basePath), self::EXCEPTION_READ_PROTECED_PATH);
		}

		// Get configuration instance
		$cfgInstance = FrameworkConfiguration::getInstance();

		// Set the base path
		$tplInstance->setBasePath($basePath);

		// Set the language and IO instances
		$tplInstance->setLanguageInstance($langInstance);
		$tplInstance->setFileIoInstance($ioInstance);

		// Set template extensions
		$tplInstance->setRawTemplateExtension($cfgInstance->readConfig('raw_template_extension'));
		$tplInstance->setCodeTemplateExtension($cfgInstance->readConfig('code_template_extension'));

		// Absolute output path for compiled templates
		$tplInstance->setCompileOutputPath(PATH . $cfgInstance->readConfig('compile_output_path'));

		// Return the prepared instance
		return $tplInstance;
	}
}

// [EOF]
?>
